"use client";
import clsx from "clsx";
import { Check, CircleX } from "lucide-react";
import { useFormState } from "react-dom";
import { Input } from "~/components/ui/input";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "~/components/ui/select";
import { Textarea } from "~/components/ui/textarea";
import { addProducer } from "~/server/actions/addProducer";
import SubmitButton from "../SubmitButton";

type Country = {
  id: string;
  name: string;
};

export default function CreateProducerForm(props: { allCountries: Country[] }) {
  const { allCountries } = props;
  const [formState, formAction] = useFormState(addProducer, {
    message: "",
    errors: undefined,
    fieldValues: {
      name: "",
      description: "",
      imageUrl: "",
      countryId: "",
    },
  });
  return (
    <form action={formAction}>
      <Input
        name="name"
        id="name"
        placeholder="Enter the name of the producer..."
        className={clsx({ "border-red-500": formState.errors?.name })}
      />
      {formState.message !== "" && !formState.errors?.name ? (
        <Check className="text-green-500" />
      ) : (
        ""
      )}
      {formState.errors?.name ? (
        <div className="flex min-w-96 items-center gap-1 text-red-500">
          <CircleX />
          <span className="text-sm">{formState.errors?.name}</span>
        </div>
      ) : (
        ""
      )}
      <Textarea
        name="description"
        id="description"
        placeholder="Enter a description of the producer..."
        className={clsx({ "border-red-500": formState.errors?.description })}
      />
      {formState.message !== "" && !formState.errors?.description ? (
        <Check className="text-green-500" />
      ) : (
        ""
      )}
      {formState.errors?.description ? (
        <div className="flex min-w-96 items-center gap-1 text-red-500">
          <CircleX />
          <span className="text-sm">{formState.errors?.description}</span>
        </div>
      ) : (
        ""
      )}
      <Input
        name="imageUrl"
        id="imageUrl"
        placeholder="Image URL"
        className={clsx({ "border-red-500": formState.errors?.imageUrl })}
      />
      {formState.message !== "" && !formState.errors?.imageUrl ? (
        <Check className="text-green-500" />
      ) : (
        ""
      )}
      {formState.errors?.imageUrl ? (
        <div className="flex min-w-96 items-center gap-1 text-red-500">
          <CircleX />
          <span className="text-sm">{formState.errors?.imageUrl}</span>
        </div>
      ) : (
        ""
      )}
      <Select name="countryId">
        <SelectTrigger className={`w-[180px] `}>
          <SelectValue placeholder="select country" />
        </SelectTrigger>
        <SelectContent>
          {allCountries.map((country) => (
            <SelectItem key={country.id} value={country.id}>
              {country.name}
            </SelectItem>
          ))}
        </SelectContent>
      </Select>
      <SubmitButton text={"producer"} />
    </form>
  );
}
