"use server";
import { eq } from "drizzle-orm";
import { db } from "../db";
import { producers } from "../db/schema";
import { ZodError, z } from "zod";
import { revalidatePath } from "next/cache";

export const addProducer = async (prevstate: any, formData: FormData) => {
  //assign formdaata to variables.
  const name = (formData.get("name") as string).toLowerCase();
  const description = (formData.get("description") as string).toLowerCase();
  const imageUrl = (formData.get("imageUrl") as string).toLowerCase();
  const countryId = formData.get("countryId") as string;

  //check if producer already exists in country
  const exists = await db
    .select({ name: producers.name })
    .from(producers)
    .where(eq(producers.name, name));

  //Define the schema for the form data
  const schema = z.object({
    name: z
      .string()
      .min(1, "Name is required")
      .refine(() => !exists[0], {
        message: `${name} already exists in selected country`,
      }),
    description: z.string(),
    imageUrl: z.string(),
    countryId: z.string().min(1, "No country selected"),
  });
  //Parse the form data using the schema for validation, and check if the name already exists
  try {
    schema.parse({
      name,
      description,
      imageUrl,
      countryId,
    });
    //If the name doesn't exist, add the country to the database abd revalidate the page
    await db
      .insert(producers)
      .values({ name, description, imageUrl, countryId });
    revalidatePath("/");
    //Return a success message
    return {
      message: "success",
      errors: undefined,
      fieldValues: {
        name: "",
        description: "",
        imageUrl: "",
        countryId: "",
      },
    };
  } catch (error) {
    const zodError = error as ZodError;
    const errorMap = zodError.flatten().fieldErrors;
    //Return an error object with the field values and errors.
    return {
      message: "error",
      errors: {
        name: errorMap["name"]?.[0] ?? "",
        description: errorMap["description"]?.[0] ?? "",
        imageUrl: errorMap["imageUrl"]?.[0] ?? "",
        countryId: errorMap["countryId"]?.[0] ?? "",
      },
      fieldValues: {
        name,
        description,
        imageUrl,
        countryId,
      },
    };
  }
};
